@@ -338,7 +338,8 @@ class Checker(BaseChecker):
 		for j in range(len(inbox_atom.entries)):
 			link = inbox_atom.entries[j].link
 			tmp = link[link.find("message_id"):]
-			message_id =  tmp[:tmp.find("&")].split("=")[1]
+			message_id = tmp[:tmp.find("&")].split("=")[1] + \
+					inbox_atom.entries[j].published.replace(':','').replace('-','')
 			ids.append(message_id)
 			if message_id not in self.notified:
 				title  = inbox_atom.entries[j].title
@@ -351,14 +352,15 @@ class Checker(BaseChecker):
 			for j in range(len(atom.entries)):
 				link = atom.entries[j].link
 				tmp = link[link.find("message_id"):]
-				message_id =  tmp[:tmp.find("&")].split("=")[1]
+				message_id = tmp[:tmp.find("&")].split("=")[1] + \
+						atom.entries[j].published.replace(':','').replace('-','')
 				ids.append(message_id)
 				if message_id not in self.notified:
 					title  = atom.entries[j].title
 					author = atom.entries[j].author
 					labeled_mails.append([author, title, label])
 
-		co = len(ids) - len(self.notified)
+		co = len(mails)
 
 		# no email, update and exit
 		status_title = ""
@@ -370,6 +372,7 @@ class Checker(BaseChecker):
 				"",
 				None
 			)
+			self.notified = []
 			log("END checking gmail account %s ..." % self.username)
 			return
 
@@ -387,7 +390,7 @@ class Checker(BaseChecker):
 			status_message += _(" Total unread mails: %s") % count
 
 			status_title = _("Account: %s") % self.username
-			if not "gmail.com" in status_title:
+			if not ("@" in status_title or "gmail.com" in status_title):
 				status_title += "@gmail.com"
 			self.emit("status-changed", 
 				count,
