@@ -2,7 +2,7 @@
 import xdg.BaseDirectory as base
 import os
 
-PACKAGE_NAME="cGmail"
+PACKAGE_NAME="cgmail"
 
 def get_data_file(filename):
 	"""
