@@ -1,5 +1,6 @@
 #
 #    Copyright (C) 2007 Marco Ferragina <marco.ferragina@gmail.com>
+#    Copyright (C) 2009 Francesco Marella <francesco.marella@gmail.com>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -22,9 +23,11 @@ class StatusListener:
 	"""
 	def __init__(self, crunner):
 		crunner.connect("checker-status-changed", self.on_status_changed)
+		crunner.connect("checker-checker-running", self.on_checker_running)
 		pass
 
-	
 	def on_status_changed(self, crunner, checker):
 		raise NotImplementedError()
 
+	def on_checker_running(self, obj):
+		pass #raise NotImplementedError()
